@@ -28,6 +28,7 @@ from .comp_metamodels import *
 from .eval_random import *
 from .eval_tail import *
 from .eval_opt import *
+from .eval_pnd import *
 from .eval_contour import *
 from .tran_pivot import *
 from .tran_shapley import *
@@ -44,3 +45,4 @@ from .eval import *
 from .fit import *
 from .psdr import *
 from .tran import *
+from .spc import *
