@@ -16,13 +16,14 @@ from pandas import Series
 
 @make_symbolic
 def var_in(series, collection):
-    """
-    Returns a boolean series where each entry denotes inclusion in the
-    provided collection. Intended for use in mask() calls.
+    """Determine if value is in collection
+
+    Returns a boolean series where each entry denotes inclusion in the provided collection. Intended for use in tran_filter() calls.
 
     Args:
         series: column to compute inclusion bools
         collection: set for inclusion calcs
+
     """
     bools = Series([s in collection for s in series])
 
@@ -31,10 +32,9 @@ def var_in(series, collection):
 
 @make_symbolic
 def is_nan(series, inv=False):
-    """Determine if boolean
+    """Determine if nan
 
-    Returns a boolean series where each entry denotes NaN or not. Intended for
-    use in mask() calls.
+    Returns a boolean series where each entry denotes NaN or not. Intended for use in tran_filter() calls.
 
     Args:
         series (Pandas series): column to compute NaN bools
@@ -50,10 +50,9 @@ def is_nan(series, inv=False):
 
 @make_symbolic
 def not_nan(series, inv=False):
-    """Determine if NOT boolean
+    """Determine if NOT nan
 
-    Returns a boolean series where each entry denotes NOT NaN or yes. Intended
-    for use in mask() calls.
+    Returns a boolean series where each entry denotes NOT NaN or yes. Intended for use in tran_filter() calls.
 
     Args:
         series (Pandas series): column to compute NOT NaN bools
