@@ -1,6 +1,6 @@
 __all__ = ["make_linear_normal"]
 
-import grama as gr
+from grama import cp_copula_independence, cp_function, cp_marginals, Model
 
 
 def limit_state(x):
@@ -9,17 +9,17 @@ def limit_state(x):
     return 1 - x1 - x2
 
 def make_linear_normal():
-    md = gr.Model("Linear-Normal Reliability Problem") >> \
-         gr.cp_function(
+    md = Model("Linear-Normal Reliability Problem") >> \
+         cp_function(
              fun=limit_state,
              var=2,
              out=["g_linear"],
              name="limit state"
          ) >> \
-         gr.cp_marginals(
+         cp_marginals(
              x0={"dist": "norm", "loc": 0, "scale": 1, "sign":+1},
              x1={"dist": "norm", "loc": 0, "scale": 1, "sign":+1}
          ) >> \
-         gr.cp_copula_independence()
+         cp_copula_independence()
 
     return md
